import moment from 'moment';
import uuid from 'uuid/v4';
import _ from 'lodash';
import {} from '../../../services/modules';
import { countTasks, fetchTasks } from '../../../services/bpm';
import config from '../../../utils/config';

const prefix = uuid();

const modelCreator = () => {
  const name = 'task';
  const namespace = _.uniqueId(prefix);
  return {
    name,
    model: {
      namespace,
      state: {
        num: 0,
        list: [],
      },
      reducers: {
        queryCountSuccess(state, { payload: num }) {
          return {
            ...state,
            num,
          };
        },
        queryTasksSuccess(state, { payload: list }) {
          return {
            ...state,
            list,
          };
        },
      },
      effects: {
        // *fetchData({ payload: { coordinate, pst, psz, params, filters} }, { put, call }) {
        //
        // }
        *fetchTasks({ payload: { pst, psz, filters } }, { put, call }) {
          const num = Number.parseInt(yield call(countTasks, filters), 10);
          yield put({ type: 'queryCountSuccess', payload: num });
          const tasks = yield call(fetchTasks, { pst, psz, filters });
          yield put({
            type: 'queryTasksSuccess',
            payload: tasks.map((task) => {
              return {
                key: `${task.pId}-${task.nId}`,
                pName: task.pName,
                nName: task.nName,
                state: task.state,
                date: moment(task.date, config.defaultDateTimeFormat),
                deadline: moment(task.deadline, config.defaultDateTimeFormat),
              };
            }),
          });
        },
      },
      subscriptions: {},
    },
  };
};

export default modelCreator;
